==> xpi-firefox-showcase-0.9.4.9.tbz: lib/xpi/{89506680-e3f4-484c-a2c0-ed711d481eda}/defaults/preferences/showcase.js <==
pref("extensions.showcase.windowPosition", 0);

pref("extensions.showcase.windowWidth", 0);
pref("extensions.showcase.windowWidthPercentage", "96");
pref("extensions.showcase.windowWidthModifier", 0);

pref("extensions.showcase.windowHeight", 0);
pref("extensions.showcase.windowHeightPercentage", "96");
pref("extensions.showcase.windowHeightModifier", 0);

pref("extensions.showcase.embeddedLocalShowcase", true);

pref("extensions.showcase.windowAttributeDialog", true);
pref("extensions.showcase.windowAttributeModal", false);
pref("extensions.showcase.windowAttributeMaximized", false);
pref("extensions.showcase.windowAttributeFullScreen", false);
pref("extensions.showcase.windowAttributeAlwaysRaised", false);
pref("extensions.showcase.windowAttributeDependent", false);
pref("extensions.showcase.windowAttributeTitleBar", true);
pref("extensions.showcase.windowAttributeTranslucent", false);

pref("extensions.showcase.windowCustomColors", false);
pref("extensions.showcase.windowCustomBackgroundColor", "#e5ecf9");
pref("extensions.showcase.windowCloseWhenBlur", false);
pref("extensions.showcase.windowCloseWhenParentFocus", true);
pref("extensions.showcase.windowCloseWhenSelect", true);
pref("extensions.showcase.windowCloseWhenZeroThumbnails", true);
pref("extensions.showcase.windowScrollType", 1);
pref("extensions.showcase.windowThumbnailPreferredMinimumSize", 200);
pref("extensions.showcase.windowAlwaysShowScrollbar", false);
pref("extensions.showcase.windowShowOnlyCurrentByDefault", false);
pref("extensions.showcase.windowZoomFitsScreen", true);
pref("extensions.showcase.windowSelectWhenOpen", false);
pref("extensions.showcase.windowDoubleClickAction", 0);
pref("extensions.showcase.windowFocusShowcase", true);

pref("extensions.showcase.tabCustomColors", true);
pref("extensions.showcase.tabCustomTitleColor", "#000000");
pref("extensions.showcase.tabCustomBackgroundColor", "#e5ecf9");
pref("extensions.showcase.tabColorizeLabel", true);
pref("extensions.showcase.tabCloseWhenBlur", false);
pref("extensions.showcase.tabCloseWhenBlur", false);
pref("extensions.showcase.tabCloseWhenSelect", true);
pref("extensions.showcase.tabCloseWhenZeroThumbnails", true);
pref("extensions.showcase.tabScrollType", 1);
pref("extensions.showcase.tabThumbnailPreferredMinimumSize", 200);
pref("extensions.showcase.tabAlwaysShowScrollbar", false);
pref("extensions.showcase.tabShowOnlyCurrentByDefault", false);
pref("extensions.showcase.tabSynchFindBar", true);
pref("extensions.showcase.tabInitialPosition", 0);
pref("extensions.showcase.tabZoomFitsScreen", true);
pref("extensions.showcase.tabSelectWhenOpen", false);
pref("extensions.showcase.tabDoubleClickAction", 0);
pref("extensions.showcase.tabFocusShowcase", true);

pref("extensions.showcase.sidebarCustomColors", false);
pref("extensions.showcase.sidebarCustomBackgroundColor", "#e5ecf9");
pref("extensions.showcase.sidebarCloseWhenSelect", false);
pref("extensions.showcase.sidebarScrollType", 1);
pref("extensions.showcase.sidebarThumbnailPreferredMinimumSize", 400);
pref("extensions.showcase.sidebarAlwaysShowScrollbar", false);
pref("extensions.showcase.sidebarShowOnlyCurrentByDefault", false);
pref("extensions.showcase.sidebarSelectWhenMouseOver", false);
pref("extensions.showcase.sidebarSelectWhenMouseOverDelay", 300);
pref("extensions.showcase.sidebarHideTabBar", false);
pref("extensions.showcase.sidebarFindBarMode", 0);
pref("extensions.showcase.sidebarZoomFitsScreen", false);
pref("extensions.showcase.sidebarSelectWhenOpen", false);
pref("extensions.showcase.sidebarDoubleClickAction", 1);
pref("extensions.showcase.sidebarFocusShowcase", false);

pref("extensions.showcase.thumbnailIdleSizeFactor", "98");
pref("extensions.showcase.thumbnailActiveAnimation", false);
pref("extensions.showcase.thumbnailActiveSizeFactor", "100");
pref("extensions.showcase.thumbnailShowLabels", true);
pref("extensions.showcase.thumbnailLabelStyle", 0);
pref("extensions.showcase.animationFrames", 1);

pref("extensions.showcase.coloredThumbnailsForMultipleWindows", true);
pref("extensions.showcase.paintThumbnailsAfterLoading", false);
pref("extensions.showcase.paintSelectedTabsFirst", true);

pref("extensions.showcase.updateThumbnailWhenContentLoaded", true);
pref("extensions.showcase.updateThumbnailWhenContentChanges", true);
pref("extensions.showcase.updateThumbnailWhenScroll", true);
pref("extensions.showcase.limitContentChangeUpdates", true);
pref("extensions.showcase.limitContentChangeUpdatesTime", 500);

pref("extensions.showcase.windowLastX", 0);
pref("extensions.showcase.windowLastY", 0);
pref("extensions.showcase.windowLastRelativeX", 0);
pref("extensions.showcase.windowLastRelativeY", 0);
pref("extensions.showcase.windowLastWidth", 0);
pref("extensions.showcase.windowLastHeight", 0);

pref("extensions.showcase.leftClickAction", 2);
pref("extensions.showcase.middleClickAction", 1);
pref("extensions.showcase.rightClickAction", 4);
pref("extensions.showcase.doubleClickOpen", false);

pref("extensions.showcase.thumbnailTooltipTitle", true);
pref("extensions.showcase.thumbnailTooltipURL", true);

pref("extensions.showcase.sidebarShowTitleStats", false);
pref("extensions.showcase.tabShowTitleStats", false);
pref("extensions.showcase.windowShowTitleStats", false);

pref("extensions.showcase.contextualActionOpen", true);
pref("extensions.showcase.contextualActionShowcaseThis", true);
pref("extensions.showcase.contextualActionClose", true);
pref("extensions.showcase.contextualActionOpen", true);
pref("extensions.showcase.contextualActionBack", false);
pref("extensions.showcase.contextualActionForward", false);
pref("extensions.showcase.contextualActionReload", false);
pref("extensions.showcase.contextualActionStop", false);
pref("extensions.showcase.contextualActionDuplicateTab", false);
pref("extensions.showcase.contextualActionMoveTab", false);
pref("extensions.showcase.contextualActionDuplicateSelected", true);
pref("extensions.showcase.contextualActionMergeSelected", true);
pref("extensions.showcase.contextualActionBookmarkPage", true);
pref("extensions.showcase.contextualActionBookmarkSelected", true);
pref("extensions.showcase.contextualActionSavePage", true);
pref("extensions.showcase.contextualActionSendPage", true);
pref("extensions.showcase.contextualActionPrint", false);
pref("extensions.showcase.contextualActionViewSource", false);
pref("extensions.showcase.contextualActionPageInfo", false);
pref("extensions.showcase.contextualActionCloseOther", true);
pref("extensions.showcase.contextualActionClose", true);
pref("extensions.showcase.contextualActionCloseTab", true);
pref("extensions.showcase.contextualActionCloseWindow", true);

pref("extensions.showcase.verticalScrollbarWidth", 18);
pref("extensions.showcase.horizontalScrollbarHeight", 18);

pref("extensions.showcase.useWindowZOrder", true);
pref("extensions.showcase.cacheSize", 100);
pref("extensions.showcase.activateCache", false);

pref("extensions.showcase.detectBlank", true);
pref("extensions.showcase.detectIETab", true);
pref("extensions.showcase.detectPlugin", true);
pref("extensions.showcase.detectImage", true);

pref("extensions.showcase.renderingType", 0);

pref("extensions.showcase.zoomScrollIncrement", 10);
pref("extensions.showcase.dragDropExclude", 3);
pref("extensions.showcase.enhancedTabBar", true);
pref("extensions.showcase.allTabsButtonMode", 0);
pref("extensions.showcase.closeLastTabKeepOpen", false);
pref("extensions.showcase.windowTabFlipping", false);
pref("extensions.showcase.tabTabFlipping", false);
pref("extensions.showcase.sidebarTabFlipping", false);

pref("extensions.showcase.thumbnailBackButton", true);
pref("extensions.showcase.thumbnailForwardButton", true);
pref("extensions.showcase.thumbnailStopButton", true);
pref("extensions.showcase.thumbnailReloadButton", true);
pref("extensions.showcase.thumbnailHistoryButton", true);
pref("extensions.showcase.newThumbnailStyle", true);

pref("extensions.showcase.imageThumbnailUpscale", true);

pref("extensions.showcase.currentVersion", "none");
pref("extensions.showcase.firstRunRedirection", true);
pref("extensions.{89506680-e3f4-484c-a2c0-ed711d481eda}.description", "chrome://showcase/locale/showcase.properties");

==> xpi-firefox-showcase-0.9.5.6.tbz: lib/xpi/{89506680-e3f4-484c-a2c0-ed711d481eda}/defaults/preferences/showcase.js <==
pref("extensions.showcase.windowPosition", 0);

pref("extensions.showcase.windowWidth", 0);
pref("extensions.showcase.windowWidthPercentage", "96");
pref("extensions.showcase.windowWidthModifier", 0);

pref("extensions.showcase.windowHeight", 0);
pref("extensions.showcase.windowHeightPercentage", "96");
pref("extensions.showcase.windowHeightModifier", 0);

pref("extensions.showcase.embeddedLocalShowcase", true);

pref("extensions.showcase.windowAttributeDialog", true);
pref("extensions.showcase.windowAttributeModal", false);
pref("extensions.showcase.windowAttributeMaximized", false);
pref("extensions.showcase.windowAttributeFullScreen", false);
pref("extensions.showcase.windowAttributeAlwaysRaised", false);
pref("extensions.showcase.windowAttributeDependent", false);
pref("extensions.showcase.windowAttributeTitleBar", true);
pref("extensions.showcase.windowAttributeTranslucent", false);

pref("extensions.showcase.windowCustomColors", false);
pref("extensions.showcase.windowCustomBackgroundColor", "#e5ecf9");
pref("extensions.showcase.windowCloseWhenBlur", false);
pref("extensions.showcase.windowCloseWhenParentFocus", true);
pref("extensions.showcase.windowCloseWhenSelect", true);
pref("extensions.showcase.windowCloseWhenZeroThumbnails", true);
pref("extensions.showcase.windowScrollType", 1);
pref("extensions.showcase.windowThumbnailPreferredMinimumSize", 200);
pref("extensions.showcase.windowAlwaysShowScrollbar", false);
pref("extensions.showcase.windowShowOnlyCurrentByDefault", false);
pref("extensions.showcase.windowZoomFitsScreen", true);
pref("extensions.showcase.windowSelectWhenOpen", false);
pref("extensions.showcase.windowDoubleClickAction", 0);
pref("extensions.showcase.windowFocusShowcase", true);

pref("extensions.showcase.tabCustomColors", true);
pref("extensions.showcase.tabCustomTitleColor", "#000000");
pref("extensions.showcase.tabCustomBackgroundColor", "#e5ecf9");
pref("extensions.showcase.tabColorizeLabel", true);
pref("extensions.showcase.tabCloseWhenBlur", false);
pref("extensions.showcase.tabCloseWhenBlur", false);
pref("extensions.showcase.tabCloseWhenSelect", true);
pref("extensions.showcase.tabCloseWhenZeroThumbnails", true);
pref("extensions.showcase.tabScrollType", 1);
pref("extensions.showcase.tabThumbnailPreferredMinimumSize", 200);
pref("extensions.showcase.tabAlwaysShowScrollbar", false);
pref("extensions.showcase.tabShowOnlyCurrentByDefault", false);
pref("extensions.showcase.tabSynchFindBar", true);
pref("extensions.showcase.tabInitialPosition", 0);
pref("extensions.showcase.tabZoomFitsScreen", true);
pref("extensions.showcase.tabSelectWhenOpen", false);
pref("extensions.showcase.tabDoubleClickAction", 0);
pref("extensions.showcase.tabFocusShowcase", true);

pref("extensions.showcase.sidebarCustomColors", false);
pref("extensions.showcase.sidebarCustomBackgroundColor", "#e5ecf9");
pref("extensions.showcase.sidebarCloseWhenSelect", false);
pref("extensions.showcase.sidebarScrollType", 1);
pref("extensions.showcase.sidebarThumbnailPreferredMinimumSize", 400);
pref("extensions.showcase.sidebarAlwaysShowScrollbar", false);
pref("extensions.showcase.sidebarShowOnlyCurrentByDefault", false);
pref("extensions.showcase.sidebarSelectWhenMouseOver", false);
pref("extensions.showcase.sidebarSelectWhenMouseOverDelay", 300);
pref("extensions.showcase.sidebarHideTabBar", false);
pref("extensions.showcase.sidebarFindBarMode", 0);
pref("extensions.showcase.sidebarZoomFitsScreen", false);
pref("extensions.showcase.sidebarSelectWhenOpen", false);
pref("extensions.showcase.sidebarDoubleClickAction", 1);
pref("extensions.showcase.sidebarFocusShowcase", false);

pref("extensions.showcase.thumbnailIdleSizeFactor", "98");
pref("extensions.showcase.thumbnailActiveAnimation", false);
pref("extensions.showcase.thumbnailActiveSizeFactor", "100");
pref("extensions.showcase.thumbnailShowLabels", true);
pref("extensions.showcase.thumbnailLabelStyle", 0);
pref("extensions.showcase.animationFrames", 1);

pref("extensions.showcase.coloredThumbnailsForMultipleWindows", true);
pref("extensions.showcase.paintThumbnailsAfterLoading", false);
pref("extensions.showcase.paintSelectedTabsFirst", true);

pref("extensions.showcase.updateThumbnailWhenContentLoaded", true);
pref("extensions.showcase.updateThumbnailWhenContentChanges", true);
pref("extensions.showcase.updateThumbnailWhenTitleChanges", true);
pref("extensions.showcase.updateThumbnailWhenScroll", true);
pref("extensions.showcase.limitContentChangeUpdates", true);
pref("extensions.showcase.limitContentChangeUpdatesTime", 500);

pref("extensions.showcase.windowLastX", 0);
pref("extensions.showcase.windowLastY", 0);
pref("extensions.showcase.windowLastRelativeX", 0);
pref("extensions.showcase.windowLastRelativeY", 0);
pref("extensions.showcase.windowLastWidth", 0);
pref("extensions.showcase.windowLastHeight", 0);

pref("extensions.showcase.leftClickAction", 2);
pref("extensions.showcase.middleClickAction", 1);
pref("extensions.showcase.rightClickAction", 4);
pref("extensions.showcase.doubleClickOpen", false);

pref("extensions.showcase.thumbnailTooltipTitle", true);
pref("extensions.showcase.thumbnailTooltipURL", true);

pref("extensions.showcase.sidebarShowTitleStats", false);
pref("extensions.showcase.tabShowTitleStats", false);
pref("extensions.showcase.windowShowTitleStats", false);

pref("extensions.showcase.contextualActionOpen", true);
pref("extensions.showcase.contextualActionShowcaseThis", true);
pref("extensions.showcase.contextualActionClose", true);
pref("extensions.showcase.contextualActionOpen", true);
pref("extensions.showcase.contextualActionBack", false);
pref("extensions.showcase.contextualActionForward", false);
pref("extensions.showcase.contextualActionReload", false);
pref("extensions.showcase.contextualActionStop", false);
pref("extensions.showcase.contextualActionDuplicateTab", false);
pref("extensions.showcase.contextualActionMoveTab", false);
pref("extensions.showcase.contextualActionDuplicateSelected", true);
pref("extensions.showcase.contextualActionMergeSelected", true);
pref("extensions.showcase.contextualActionBookmarkPage", true);
pref("extensions.showcase.contextualActionBookmarkSelected", true);
pref("extensions.showcase.contextualActionSavePage", true);
pref("extensions.showcase.contextualActionSendPage", true);
pref("extensions.showcase.contextualActionPrint", false);
pref("extensions.showcase.contextualActionViewSource", false);
pref("extensions.showcase.contextualActionPageInfo", false);
pref("extensions.showcase.contextualActionCloseOther", true);
pref("extensions.showcase.contextualActionClose", true);
pref("extensions.showcase.contextualActionCloseTab", true);
pref("extensions.showcase.contextualActionCloseWindow", true);

pref("extensions.showcase.verticalScrollbarWidth", 18);
pref("extensions.showcase.horizontalScrollbarHeight", 18);

pref("extensions.showcase.useWindowZOrder", true);
pref("extensions.showcase.cacheSize", 100);
pref("extensions.showcase.activateCache", false);

pref("extensions.showcase.detectBlank", true);
pref("extensions.showcase.detectIETab", true);
pref("extensions.showcase.detectPlugin", true);
pref("extensions.showcase.detectImage", true);

pref("extensions.showcase.renderingType", 0);

pref("extensions.showcase.zoomScrollIncrement", 10);
pref("extensions.showcase.dragDropExclude", 0);
pref("extensions.showcase.enhancedTabBar", true);
pref("extensions.showcase.allTabsButtonMode", 0);
pref("extensions.showcase.closeLastTabKeepOpen", false);
pref("extensions.showcase.windowTabFlipping", false);
pref("extensions.showcase.tabTabFlipping", false);
pref("extensions.showcase.sidebarTabFlipping", false);

pref("extensions.showcase.thumbnailBackButton", true);
pref("extensions.showcase.thumbnailForwardButton", true);
pref("extensions.showcase.thumbnailStopButton", true);
pref("extensions.showcase.thumbnailReloadButton", true);
pref("extensions.showcase.thumbnailHistoryButton", true);
pref("extensions.showcase.newThumbnailStyle", true);

pref("extensions.showcase.imageThumbnailUpscale", true);

pref("extensions.showcase.currentVersion", "none");
pref("extensions.showcase.firstRunRedirection", true);
pref("extensions.{89506680-e3f4-484c-a2c0-ed711d481eda}.description", "chrome://showcase/locale/showcase.properties");
